@@ -14,13 +14,13 @@ class SassTest < Minitest::Test
   end
 
   it 'renders inline Sass strings' do
-    sass_app { sass "#sass\n  :background-color white\n" }
+    sass_app { sass "#sass\n  background-color: white\n" }
     assert ok?
     assert_equal "#sass {\n  background-color: white; }\n", body
   end
 
   it 'defaults content type to css' do
-    sass_app { sass "#sass\n  :background-color white\n" }
+    sass_app { sass "#sass\n  background-color: white\n" }
     assert ok?
     assert_equal "text/css;charset=utf-8", response['Content-Type']
   end
@@ -28,7 +28,7 @@ class SassTest < Minitest::Test
   it 'defaults allows setting content type per route' do
     sass_app do
       content_type :html
-      sass "#sass\n  :background-color white\n"
+      sass "#sass\n  background-color: white\n"
     end
     assert ok?
     assert_equal "text/html;charset=utf-8", response['Content-Type']
@@ -36,7 +36,7 @@ class SassTest < Minitest::Test
 
   it 'defaults allows setting content type globally' do
     sass_app(:sass => { :content_type => 'html' }) {
-      sass "#sass\n  :background-color white\n"
+      sass "#sass\n  background-color: white\n"
     }
     assert ok?
     assert_equal "text/html;charset=utf-8", response['Content-Type']
@@ -62,7 +62,7 @@ class SassTest < Minitest::Test
   it "passes SASS options to the Sass engine" do
     sass_app do
       sass(
-        "#sass\n  :background-color white\n  :color black\n",
+        "#sass\n  background-color: white\n  color: black\n",
         :style => :compact
       )
     end
@@ -73,7 +73,7 @@ class SassTest < Minitest::Test
   it "passes default SASS options to the Sass engine" do
     mock_app do
       set :sass, {:style => :compact} # default Sass style is :nested
-      get('/') { sass("#sass\n  :background-color white\n  :color black\n") }
+      get('/') { sass("#sass\n  background-color: white\n  color: black\n") }
     end
     get '/'
     assert ok?
@@ -111,5 +111,5 @@ class SassTest < Minitest::Test
 end
 
 rescue LoadError
-  warn "#{$!.to_s}: skipping sass tests"
+  warn "#{$!}: skipping sass tests"
 end
